package com.lyg.application.controller;

import cn.dev33.satoken.util.SaResult;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import java.util.List;
import com.lyg.common.Constants;
import com.lyg.common.util.StringUtil;
import com.lyg.framework.log.OpLog;
import com.lyg.system.controller.BaseController;
import com.lyg.framework.accesslimit.AccessLimit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;
import com.lyg.application.entity.TaCategory;
import com.lyg.application.service.TaCategoryService;

 /**
 * 分类;(ta_category)表控制层
 * @author : http://njyunzhi.com
 * @date : 2024-3-22
 */
@Api(tags = "分类对象功能接口")
@RestController
@RequestMapping("/")
public class TaCategoryController extends BaseController {
    
    @Autowired
    private TaCategoryService taCategoryService;
    
    /** 
     * 通过ID查询单条数据 
     *
     * @param id 主键
     * @return 实例对象
     */
    @OpLog(module = "分类", action = "查询单条数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过ID查询单条数据")
    @GetMapping("/taCategory/{id}")
    public SaResult queryById(@ApiParam("对象ID") @PathVariable String id) throws Exception {
        return SaResult.data(taCategoryService.getById(id));
    }
    
    /** 
     * 分页查询
     *
     * @param pageNum 当前页码
     * @param pageSize 每页条数
     * @return 查询结果
     */
    @OpLog(module = "分类", action = "分页列表查询")
    @AccessLimit()
    @ApiOperation("分页查询")
    @GetMapping("/taCategory")
    public SaResult list(@ApiParam("页码") @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                            @ApiParam("单页数据量") @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                            @ApiParam("正序排列") @RequestParam(value ="sortAsc", required = false) String sortAsc,
                         @ApiParam("倒序排列") @RequestParam(value ="sortDesc", defaultValue = "create_date") String sortDesc) throws Exception {
        
        IPage<TaCategory> pg = new Page<>(pageNum, pageSize);
        QueryWrapper<TaCategory> queryWrapper = new QueryWrapper<>();
        queryWrapper.orderByAsc(StringUtil.isNotEmpty(sortAsc), StringUtil.humpToLine(sortAsc));
        queryWrapper.orderByDesc(StringUtil.isNotEmpty(sortDesc), StringUtil.humpToLine(sortDesc));
        IPage<TaCategory> result = taCategoryService.page(pg, queryWrapper);
        
        return SaResult.data(result);
    }
    
    /** 
     * 新增数据
     *
     * @param taCategory 实例对象
     * @return 实例对象
     */
    @OpLog(module = "分类", action = "新增数据")
    @AccessLimit()
    @ApiOperation("新增数据")
    @PostMapping("/taCategory")
    public SaResult add(@ApiParam("对象实体") @Validated @RequestBody TaCategory taCategory) throws Exception {
        taCategoryService.save(taCategory);
        return SaResult.data(taCategory);
    }
    
    /** 
     * 更新数据
     *
     * @param taCategory 实例对象
     * @return 实例对象
     */
    @OpLog(module = "分类", action = "更新数据")
    @AccessLimit()
    @ApiOperation("更新数据")
    @PutMapping("/taCategory/{id}")
    public SaResult edit(@ApiParam("对象实体") @Validated @RequestBody TaCategory taCategory,
                            @ApiParam("对象ID") @PathVariable String id ) throws Exception {
        taCategory.setCategoryId(id);
        taCategoryService.updateById(taCategory);
        return SaResult.data(taCategory);
    }
    
    /** 
     * 通过主键删除数据
     *
     * @param id 主键
     * @return 是否成功
     */
    @OpLog(module = "分类", action = "删除数据", desc = "ID：{{#id}}")
    @AccessLimit()
    @ApiOperation("通过主键删除数据")
    @DeleteMapping("/taCategory/{id}")
    public SaResult deleteById(@ApiParam("对象ID") @PathVariable String id){
        taCategoryService.removeById(id);
        return SaResult.data("success");
    }
}